==> kubernetes-model-core-5.11.2-sources.jar: io/fabric8/kubernetes/api/model/AffinityFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class AffinityFluentImpl<A extends io.fabric8.kubernetes.api.model.AffinityFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.AffinityFluent<A>{
  public AffinityFluentImpl() {
  }
  public AffinityFluentImpl(io.fabric8.kubernetes.api.model.Affinity instance) {
    this.withNodeAffinity(instance.getNodeAffinity()); 
    this.withPodAffinity(instance.getPodAffinity()); 
    this.withPodAntiAffinity(instance.getPodAntiAffinity()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.NodeAffinityBuilder nodeAffinity;
  private io.fabric8.kubernetes.api.model.PodAffinityBuilder podAffinity;
  private io.fabric8.kubernetes.api.model.PodAntiAffinityBuilder podAntiAffinity;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildNodeAffinity instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.NodeAffinity getNodeAffinity() {
    return this.nodeAffinity!=null?this.nodeAffinity.build():null;
  }
  public io.fabric8.kubernetes.api.model.NodeAffinity buildNodeAffinity() {
    return this.nodeAffinity!=null?this.nodeAffinity.build():null;
  }
  public A withNodeAffinity(io.fabric8.kubernetes.api.model.NodeAffinity nodeAffinity) {
    _visitables.get("nodeAffinity").remove(this.nodeAffinity);
    if (nodeAffinity!=null){ this.nodeAffinity= new io.fabric8.kubernetes.api.model.NodeAffinityBuilder(nodeAffinity); _visitables.get("nodeAffinity").add(this.nodeAffinity);} return (A) this;
  }
  public java.lang.Boolean hasNodeAffinity() {
    return this.nodeAffinity != null;
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<A> withNewNodeAffinity() {
    return new io.fabric8.kubernetes.api.model.AffinityFluentImpl.NodeAffinityNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<A> withNewNodeAffinityLike(io.fabric8.kubernetes.api.model.NodeAffinity item) {
    return new io.fabric8.kubernetes.api.model.AffinityFluentImpl.NodeAffinityNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<A> editNodeAffinity() {
    return withNewNodeAffinityLike(getNodeAffinity());
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<A> editOrNewNodeAffinity() {
    return withNewNodeAffinityLike(getNodeAffinity() != null ? getNodeAffinity(): new io.fabric8.kubernetes.api.model.NodeAffinityBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<A> editOrNewNodeAffinityLike(io.fabric8.kubernetes.api.model.NodeAffinity item) {
    return withNewNodeAffinityLike(getNodeAffinity() != null ? getNodeAffinity(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPodAffinity instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.PodAffinity getPodAffinity() {
    return this.podAffinity!=null?this.podAffinity.build():null;
  }
  public io.fabric8.kubernetes.api.model.PodAffinity buildPodAffinity() {
    return this.podAffinity!=null?this.podAffinity.build():null;
  }
  public A withPodAffinity(io.fabric8.kubernetes.api.model.PodAffinity podAffinity) {
    _visitables.get("podAffinity").remove(this.podAffinity);
    if (podAffinity!=null){ this.podAffinity= new io.fabric8.kubernetes.api.model.PodAffinityBuilder(podAffinity); _visitables.get("podAffinity").add(this.podAffinity);} return (A) this;
  }
  public java.lang.Boolean hasPodAffinity() {
    return this.podAffinity != null;
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<A> withNewPodAffinity() {
    return new io.fabric8.kubernetes.api.model.AffinityFluentImpl.PodAffinityNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<A> withNewPodAffinityLike(io.fabric8.kubernetes.api.model.PodAffinity item) {
    return new io.fabric8.kubernetes.api.model.AffinityFluentImpl.PodAffinityNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<A> editPodAffinity() {
    return withNewPodAffinityLike(getPodAffinity());
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<A> editOrNewPodAffinity() {
    return withNewPodAffinityLike(getPodAffinity() != null ? getPodAffinity(): new io.fabric8.kubernetes.api.model.PodAffinityBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<A> editOrNewPodAffinityLike(io.fabric8.kubernetes.api.model.PodAffinity item) {
    return withNewPodAffinityLike(getPodAffinity() != null ? getPodAffinity(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPodAntiAffinity instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.PodAntiAffinity getPodAntiAffinity() {
    return this.podAntiAffinity!=null?this.podAntiAffinity.build():null;
  }
  public io.fabric8.kubernetes.api.model.PodAntiAffinity buildPodAntiAffinity() {
    return this.podAntiAffinity!=null?this.podAntiAffinity.build():null;
  }
  public A withPodAntiAffinity(io.fabric8.kubernetes.api.model.PodAntiAffinity podAntiAffinity) {
    _visitables.get("podAntiAffinity").remove(this.podAntiAffinity);
    if (podAntiAffinity!=null){ this.podAntiAffinity= new io.fabric8.kubernetes.api.model.PodAntiAffinityBuilder(podAntiAffinity); _visitables.get("podAntiAffinity").add(this.podAntiAffinity);} return (A) this;
  }
  public java.lang.Boolean hasPodAntiAffinity() {
    return this.podAntiAffinity != null;
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<A> withNewPodAntiAffinity() {
    return new io.fabric8.kubernetes.api.model.AffinityFluentImpl.PodAntiAffinityNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<A> withNewPodAntiAffinityLike(io.fabric8.kubernetes.api.model.PodAntiAffinity item) {
    return new io.fabric8.kubernetes.api.model.AffinityFluentImpl.PodAntiAffinityNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<A> editPodAntiAffinity() {
    return withNewPodAntiAffinityLike(getPodAntiAffinity());
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<A> editOrNewPodAntiAffinity() {
    return withNewPodAntiAffinityLike(getPodAntiAffinity() != null ? getPodAntiAffinity(): new io.fabric8.kubernetes.api.model.PodAntiAffinityBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<A> editOrNewPodAntiAffinityLike(io.fabric8.kubernetes.api.model.PodAntiAffinity item) {
    return withNewPodAntiAffinityLike(getPodAntiAffinity() != null ? getPodAntiAffinity(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap<java.lang.String,java.lang.Object>(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AffinityFluentImpl that = (AffinityFluentImpl) o;
    if (nodeAffinity != null ? !nodeAffinity.equals(that.nodeAffinity) :that.nodeAffinity != null) return false;
    if (podAffinity != null ? !podAffinity.equals(that.podAffinity) :that.podAffinity != null) return false;
    if (podAntiAffinity != null ? !podAntiAffinity.equals(that.podAntiAffinity) :that.podAntiAffinity != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(nodeAffinity,  podAffinity,  podAntiAffinity,  additionalProperties,  super.hashCode());
  }
  public class NodeAffinityNestedImpl<N> extends io.fabric8.kubernetes.api.model.NodeAffinityFluentImpl<io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<N>> implements io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    NodeAffinityNestedImpl(io.fabric8.kubernetes.api.model.NodeAffinity item) {
      this.builder = new io.fabric8.kubernetes.api.model.NodeAffinityBuilder(this, item);
    }
    NodeAffinityNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.NodeAffinityBuilder(this);
    }
    io.fabric8.kubernetes.api.model.NodeAffinityBuilder builder;
    public N and() {
      return (N) AffinityFluentImpl.this.withNodeAffinity(builder.build());
    }
    public N endNodeAffinity() {
      return and();
    }
    
  }
  public class PodAffinityNestedImpl<N> extends io.fabric8.kubernetes.api.model.PodAffinityFluentImpl<io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<N>> implements io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PodAffinityNestedImpl(io.fabric8.kubernetes.api.model.PodAffinity item) {
      this.builder = new io.fabric8.kubernetes.api.model.PodAffinityBuilder(this, item);
    }
    PodAffinityNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.PodAffinityBuilder(this);
    }
    io.fabric8.kubernetes.api.model.PodAffinityBuilder builder;
    public N and() {
      return (N) AffinityFluentImpl.this.withPodAffinity(builder.build());
    }
    public N endPodAffinity() {
      return and();
    }
    
  }
  public class PodAntiAffinityNestedImpl<N> extends io.fabric8.kubernetes.api.model.PodAntiAffinityFluentImpl<io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<N>> implements io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PodAntiAffinityNestedImpl(io.fabric8.kubernetes.api.model.PodAntiAffinity item) {
      this.builder = new io.fabric8.kubernetes.api.model.PodAntiAffinityBuilder(this, item);
    }
    PodAntiAffinityNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.PodAntiAffinityBuilder(this);
    }
    io.fabric8.kubernetes.api.model.PodAntiAffinityBuilder builder;
    public N and() {
      return (N) AffinityFluentImpl.this.withPodAntiAffinity(builder.build());
    }
    public N endPodAntiAffinity() {
      return and();
    }
    
  }
  
}

==> kubernetes-model-core-5.12.4-sources.jar: io/fabric8/kubernetes/api/model/AffinityFluentImpl.java <==
package io.fabric8.kubernetes.api.model;

import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import java.lang.Object;
import java.util.Map;

 /**
  * Generated
  */
public class AffinityFluentImpl<A extends io.fabric8.kubernetes.api.model.AffinityFluent<A>> extends io.fabric8.kubernetes.api.builder.BaseFluent<A> implements io.fabric8.kubernetes.api.model.AffinityFluent<A>{
  public AffinityFluentImpl() {
  }
  public AffinityFluentImpl(io.fabric8.kubernetes.api.model.Affinity instance) {
    this.withNodeAffinity(instance.getNodeAffinity()); 
    this.withPodAffinity(instance.getPodAffinity()); 
    this.withPodAntiAffinity(instance.getPodAntiAffinity()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private io.fabric8.kubernetes.api.model.NodeAffinityBuilder nodeAffinity;
  private io.fabric8.kubernetes.api.model.PodAffinityBuilder podAffinity;
  private io.fabric8.kubernetes.api.model.PodAntiAffinityBuilder podAntiAffinity;
  private java.util.Map<java.lang.String,java.lang.Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildNodeAffinity instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.NodeAffinity getNodeAffinity() {
    return this.nodeAffinity!=null?this.nodeAffinity.build():null;
  }
  public io.fabric8.kubernetes.api.model.NodeAffinity buildNodeAffinity() {
    return this.nodeAffinity!=null?this.nodeAffinity.build():null;
  }
  public A withNodeAffinity(io.fabric8.kubernetes.api.model.NodeAffinity nodeAffinity) {
    _visitables.get("nodeAffinity").remove(this.nodeAffinity);
    if (nodeAffinity!=null){ this.nodeAffinity= new io.fabric8.kubernetes.api.model.NodeAffinityBuilder(nodeAffinity); _visitables.get("nodeAffinity").add(this.nodeAffinity);} return (A) this;
  }
  public java.lang.Boolean hasNodeAffinity() {
    return this.nodeAffinity != null;
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<A> withNewNodeAffinity() {
    return new io.fabric8.kubernetes.api.model.AffinityFluentImpl.NodeAffinityNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<A> withNewNodeAffinityLike(io.fabric8.kubernetes.api.model.NodeAffinity item) {
    return new io.fabric8.kubernetes.api.model.AffinityFluentImpl.NodeAffinityNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<A> editNodeAffinity() {
    return withNewNodeAffinityLike(getNodeAffinity());
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<A> editOrNewNodeAffinity() {
    return withNewNodeAffinityLike(getNodeAffinity() != null ? getNodeAffinity(): new io.fabric8.kubernetes.api.model.NodeAffinityBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<A> editOrNewNodeAffinityLike(io.fabric8.kubernetes.api.model.NodeAffinity item) {
    return withNewNodeAffinityLike(getNodeAffinity() != null ? getNodeAffinity(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPodAffinity instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.PodAffinity getPodAffinity() {
    return this.podAffinity!=null?this.podAffinity.build():null;
  }
  public io.fabric8.kubernetes.api.model.PodAffinity buildPodAffinity() {
    return this.podAffinity!=null?this.podAffinity.build():null;
  }
  public A withPodAffinity(io.fabric8.kubernetes.api.model.PodAffinity podAffinity) {
    _visitables.get("podAffinity").remove(this.podAffinity);
    if (podAffinity!=null){ this.podAffinity= new io.fabric8.kubernetes.api.model.PodAffinityBuilder(podAffinity); _visitables.get("podAffinity").add(this.podAffinity);} return (A) this;
  }
  public java.lang.Boolean hasPodAffinity() {
    return this.podAffinity != null;
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<A> withNewPodAffinity() {
    return new io.fabric8.kubernetes.api.model.AffinityFluentImpl.PodAffinityNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<A> withNewPodAffinityLike(io.fabric8.kubernetes.api.model.PodAffinity item) {
    return new io.fabric8.kubernetes.api.model.AffinityFluentImpl.PodAffinityNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<A> editPodAffinity() {
    return withNewPodAffinityLike(getPodAffinity());
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<A> editOrNewPodAffinity() {
    return withNewPodAffinityLike(getPodAffinity() != null ? getPodAffinity(): new io.fabric8.kubernetes.api.model.PodAffinityBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<A> editOrNewPodAffinityLike(io.fabric8.kubernetes.api.model.PodAffinity item) {
    return withNewPodAffinityLike(getPodAffinity() != null ? getPodAffinity(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildPodAntiAffinity instead.
   * @return The buildable object.
   */
  @java.lang.Deprecated
  public io.fabric8.kubernetes.api.model.PodAntiAffinity getPodAntiAffinity() {
    return this.podAntiAffinity!=null?this.podAntiAffinity.build():null;
  }
  public io.fabric8.kubernetes.api.model.PodAntiAffinity buildPodAntiAffinity() {
    return this.podAntiAffinity!=null?this.podAntiAffinity.build():null;
  }
  public A withPodAntiAffinity(io.fabric8.kubernetes.api.model.PodAntiAffinity podAntiAffinity) {
    _visitables.get("podAntiAffinity").remove(this.podAntiAffinity);
    if (podAntiAffinity!=null){ this.podAntiAffinity= new io.fabric8.kubernetes.api.model.PodAntiAffinityBuilder(podAntiAffinity); _visitables.get("podAntiAffinity").add(this.podAntiAffinity);} return (A) this;
  }
  public java.lang.Boolean hasPodAntiAffinity() {
    return this.podAntiAffinity != null;
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<A> withNewPodAntiAffinity() {
    return new io.fabric8.kubernetes.api.model.AffinityFluentImpl.PodAntiAffinityNestedImpl();
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<A> withNewPodAntiAffinityLike(io.fabric8.kubernetes.api.model.PodAntiAffinity item) {
    return new io.fabric8.kubernetes.api.model.AffinityFluentImpl.PodAntiAffinityNestedImpl(item);
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<A> editPodAntiAffinity() {
    return withNewPodAntiAffinityLike(getPodAntiAffinity());
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<A> editOrNewPodAntiAffinity() {
    return withNewPodAntiAffinityLike(getPodAntiAffinity() != null ? getPodAntiAffinity(): new io.fabric8.kubernetes.api.model.PodAntiAffinityBuilder().build());
  }
  public io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<A> editOrNewPodAntiAffinityLike(io.fabric8.kubernetes.api.model.PodAntiAffinity item) {
    return withNewPodAntiAffinityLike(getPodAntiAffinity() != null ? getPodAntiAffinity(): item);
  }
  public A addToAdditionalProperties(java.lang.String key,java.lang.Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new java.util.LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.lang.String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public java.util.Map<java.lang.String,java.lang.Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(java.util.Map<java.lang.String,java.lang.Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new java.util.LinkedHashMap(additionalProperties);} return (A) this;
  }
  public java.lang.Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    AffinityFluentImpl that = (AffinityFluentImpl) o;
    if (nodeAffinity != null ? !nodeAffinity.equals(that.nodeAffinity) :that.nodeAffinity != null) return false;
    if (podAffinity != null ? !podAffinity.equals(that.podAffinity) :that.podAffinity != null) return false;
    if (podAntiAffinity != null ? !podAntiAffinity.equals(that.podAntiAffinity) :that.podAntiAffinity != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(nodeAffinity,  podAffinity,  podAntiAffinity,  additionalProperties,  super.hashCode());
  }
  public class NodeAffinityNestedImpl<N> extends io.fabric8.kubernetes.api.model.NodeAffinityFluentImpl<io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<N>> implements io.fabric8.kubernetes.api.model.AffinityFluent.NodeAffinityNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    NodeAffinityNestedImpl(io.fabric8.kubernetes.api.model.NodeAffinity item) {
      this.builder = new io.fabric8.kubernetes.api.model.NodeAffinityBuilder(this, item);
    }
    NodeAffinityNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.NodeAffinityBuilder(this);
    }
    io.fabric8.kubernetes.api.model.NodeAffinityBuilder builder;
    public N and() {
      return (N) AffinityFluentImpl.this.withNodeAffinity(builder.build());
    }
    public N endNodeAffinity() {
      return and();
    }
    
  }
  public class PodAffinityNestedImpl<N> extends io.fabric8.kubernetes.api.model.PodAffinityFluentImpl<io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<N>> implements io.fabric8.kubernetes.api.model.AffinityFluent.PodAffinityNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PodAffinityNestedImpl(io.fabric8.kubernetes.api.model.PodAffinity item) {
      this.builder = new io.fabric8.kubernetes.api.model.PodAffinityBuilder(this, item);
    }
    PodAffinityNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.PodAffinityBuilder(this);
    }
    io.fabric8.kubernetes.api.model.PodAffinityBuilder builder;
    public N and() {
      return (N) AffinityFluentImpl.this.withPodAffinity(builder.build());
    }
    public N endPodAffinity() {
      return and();
    }
    
  }
  public class PodAntiAffinityNestedImpl<N> extends io.fabric8.kubernetes.api.model.PodAntiAffinityFluentImpl<io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<N>> implements io.fabric8.kubernetes.api.model.AffinityFluent.PodAntiAffinityNested<N>,io.fabric8.kubernetes.api.builder.Nested<N>{
    PodAntiAffinityNestedImpl(io.fabric8.kubernetes.api.model.PodAntiAffinity item) {
      this.builder = new io.fabric8.kubernetes.api.model.PodAntiAffinityBuilder(this, item);
    }
    PodAntiAffinityNestedImpl() {
      this.builder = new io.fabric8.kubernetes.api.model.PodAntiAffinityBuilder(this);
    }
    io.fabric8.kubernetes.api.model.PodAntiAffinityBuilder builder;
    public N and() {
      return (N) AffinityFluentImpl.this.withPodAntiAffinity(builder.build());
    }
    public N endPodAntiAffinity() {
      return and();
    }
    
  }
  
}
